==> ctf_builder-0.0.11.tar.gz: ctf_builder-0.0.11/ctf_builder/cmd/docker/deploy.py <==
import argparse
import dataclasses
import typing

import docker
import docker.models.networks

from ...error import LibError, SkipError
from ...models.challenge import Track
from ...models.deploy.base import DockerDeployContext
from ..common import CliContext, WrapContext, cli_challenge_wrapper, get_challenges


@dataclasses.dataclass(frozen=True)
class Args:
    challenge: typing.Sequence[str] = dataclasses.field(default_factory=list)


@dataclasses.dataclass(frozen=True)
class Context(WrapContext):
    docker_client: typing.Optional[docker.DockerClient] = dataclasses.field(
        default=None
    )


def deploy(track: Track, context: Context) -> typing.Sequence[LibError]:
    if not track.deploy:
        return [SkipError()]

    errors: typing.List[LibError] = []
    for i, deployer in enumerate(track.deploy):
        errors += deployer.docker_deploy(
            DockerDeployContext(
                name=f"{track.tag or track.name}_{i}",
                root=context.challenge_path,
                docker_client=context.docker_client,
                network=None,
            ),
        )

    return errors


def cli_args(parser: argparse.ArgumentParser, root_directory: str) -> None:
    parser.add_argument(
        "-c",
        "--challenge",
        action="append",
        choices=get_challenges(root_directory) or [],
        help="Name of challenges",
        default=[],
    )


def cli(args: Args, cli_context: CliContext) -> bool:
    context = Context(
        challenge_path="",
        error_prefix=[],
        skip_inactive=False,
        docker_client=cli_context.docker_client,
    )

    return cli_challenge_wrapper(
        root_directory=cli_context.root_directory,
        challenges=args.challenge if args.challenge else None,
        context=context,
        callback=deploy,
        console=cli_context.console,
    )

==> ctf_builder-0.0.17.tar.gz: ctf_builder-0.0.17/ctf_builder/cmd/docker/deploy.py <==
import argparse
import dataclasses
import typing

import docker
import docker.models.networks

from ...error import LibError, SkipError
from ...models.challenge import Track
from ...models.deploy.base import DockerDeployContext
from ..common import CliContext, WrapContext, cli_challenge_wrapper, get_challenges


@dataclasses.dataclass(frozen=True)
class Args:
    challenge: typing.Sequence[str] = dataclasses.field(default_factory=list)


@dataclasses.dataclass(frozen=True)
class Context(WrapContext):
    docker_client: typing.Optional[docker.DockerClient] = dataclasses.field(
        default=None
    )


def deploy(track: Track, context: Context) -> typing.Sequence[LibError]:
    if not track.deploy:
        return [SkipError()]

    errors: typing.List[LibError] = []
    for i, deployer in enumerate(track.deploy):
        errors += deployer.docker_deploy(
            DockerDeployContext(
                name=f"{track.tag or track.name}-{i}",
                root=context.challenge_path,
                docker_client=context.docker_client,
                network=None,
            ),
        )

    return errors


def cli_args(parser: argparse.ArgumentParser, root_directory: str) -> None:
    parser.add_argument(
        "-c",
        "--challenge",
        action="append",
        choices=get_challenges(root_directory) or [],
        help="Name of challenges",
        default=[],
    )


def cli(args: Args, cli_context: CliContext) -> bool:
    context = Context(
        challenge_path="",
        error_prefix=[],
        skip_inactive=False,
        docker_client=cli_context.docker_client,
    )

    return cli_challenge_wrapper(
        root_directory=cli_context.root_directory,
        challenges=args.challenge if args.challenge else None,
        context=context,
        callback=deploy,
        console=cli_context.console,
    )
